import { NativeEventEmitter, NativeModules, Platform } from 'react-native';
const LINKING_ERROR = `The package 'react-native-cloudinary-sdk' doesn't seem to be linked. Make sure: \n\n` + Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo managed workflow\n';
const CloudinarySdk = NativeModules.CloudinarySdk ? NativeModules.CloudinarySdk : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }

});
const emitter = new NativeEventEmitter(CloudinarySdk);
export let CloudinaryEvent;

(function (CloudinaryEvent) {
  CloudinaryEvent["UPLOAD_PROGRESS_EVENT"] = "progressChanged";
})(CloudinaryEvent || (CloudinaryEvent = {}));

const {
  ImageUrlType,
  VideoUrlType,
  RawUrlType,
  AutoUrlType
} = CloudinarySdk.getConstants();
export const URL_TYPES = {
  image: ImageUrlType,
  video: VideoUrlType,
  raw: RawUrlType,
  auto: AutoUrlType
};

function addEventListener(event, listener) {
  return emitter.addListener(event, listener);
}

const listeners = {};

const addEventListenerForUID = (uid, event, listener) => {
  removeSubscriptionForUID(uid);
  listeners[uid] = addEventListener(event, listener);
};

const removeSubscriptionForUID = key => {
  const previousListener = listeners[key];

  if (previousListener) {
    previousListener.remove();
    listeners[key] = undefined;
  }
};

export function setup(options) {
  return CloudinarySdk.setup(options);
}
export const cancelUpload = uid => {
  CloudinarySdk.cancel(uid);
};
export const upload = async (params, onProgress, onUID) => {
  const uid = Math.random().toString(36).substring(2, 15) + Math.random().toString(36).substring(2, 15);
  onUID === null || onUID === void 0 ? void 0 : onUID(uid);

  if (onProgress) {
    addEventListenerForUID(uid, CloudinaryEvent.UPLOAD_PROGRESS_EVENT, data => {
      if (uid === data.uid) {
        onProgress(data);
      }
    });
  }

  const result = await CloudinarySdk.upload({
    uid,
    ...params
  });

  if (onProgress) {
    removeSubscriptionForUID(uid);
  }

  return result;
};
//# sourceMappingURL=index.js.map